Scene

Struct Scene 

pub struct Scene {
    pub triangles: Vec<Triangle>,
    pub materials: Vec<Material>,
    pub bounds: BoundingBox,
}
A complete 3D scene with all the data required for voxelization.

Fields

triangles: Vec<Triangle>

All triangles contained within all instances of models of the scene.

The scene does not distinguish models. If you have a model with multiple instances, you should just expand them all into different triangles.

materials: Vec<Material>

All materials contained within the scene

bounds: BoundingBox

The bounding box of all triangles within the scene.

During voxelization, the voxels (which should all be positioned within the bounding box of the scene) will be translated so that instead of starting at min and ending at max, they will start at 0, 0, 0 and end at size instead.